class QuickCodesController < ApplicationController
  model_data_store(QuickCode)

  def create
    @model = QuickCode.new do |m|
      m.code = model_params[:code]
      m.style_id = model_params[:style_id]
      m.style_type_id = model_params[:style_type_id]
      m.style_material_id = model_params[:style_material_id]
    end

    if @model.save
      render json: @model, status: :created
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def apply_sort(models, sort)
    if sort&.[](:id) == "style_type_name"
      QuickCode.joins(:style_type).order("style_types.style_type #{sort[:desc] == "true" ? "DESC" : "ASC"}")
    elsif sort&.[](:id) == "style_name"
      QuickCode.joins(:style_material).order("style_materials.material_description #{sort[:desc] == "true" ? "DESC" : "ASC"}")
    elsif sort&.[](:id) == "style_material_name"
      QuickCode.joins(:style).order("styles.style #{sort[:desc] == "true" ? "DESC" : "ASC"}")
    else
      super(models, sort)
    end
  end

  private

  def before_set_targets
    @models.eager_load(:style, :style_material, :style_type)
  end

  # Only allow a list of trusted parameters through.
  def model_params
    params.require(:quick_code).permit(:quick_code_id, :code, :style_id, :style_material_id, :style_type_id)
  end
end
