import * as React from 'react';
import {t} from '@lingui/macro';
import {Box, Grid, Typography} from '@material-ui/core';
import {observer} from 'mobx-react-lite';
import {GeneratedField} from './GeneratedField';
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";
import {LevelHeader} from "./LevelHeader";
import {ExcludedFieldKeysForEdgeOnlyJobType, Field} from "../../../stores/_FieldConstants";
import {LevelWrapper} from './LevelWrapper';
import {CurrentUserConfig} from "../../../stores/ConfigStore";
import {useModelContext} from "@rx-suite/ui";

export const PerEyeFields = observer(() => {
    const store = useOrderEntryStore();
    const eyeGroups: { [index: number]: Field[] } = {};
    const isEdgeOnlyJob = store.order?.isEdgeOnlyJob || false;

    if (isEdgeOnlyJob) {
        store.perEye.filter(f => !ExcludedFieldKeysForEdgeOnlyJobType.includes(f.name)).forEach(f => {
            eyeGroups[f.level] = eyeGroups[f.level] || [];
            eyeGroups[f.level].push(f);
        });
    } else {
        store.perEye.forEach(f => {
            eyeGroups[f.level] = eyeGroups[f.level] || [];
            eyeGroups[f.level].push(f);
        });
    }

    const eyes = [] as string[];
    if (store.rightVisible) {
        eyes.push('rt');
    }
    if (store.leftVisible) {
        eyes.push('lt');
    }
    if (!eyes.length) {
        return null;
    }

    if(!CurrentUserConfig.get().allow_personalization) {
        delete eyeGroups[4];
        delete eyeGroups[5];
        delete eyeGroups[6];
    }

    return (
        <>
            {
                Object.entries(eyeGroups).map(([level, arr]) => (
                    <LevelWrapper key={level} level={level}>
                        <Grid item xs={12}>
                            <Grid container spacing={4}>
                                <Grid item xs={12} lg={12}>
                                    <LevelHeader level={level}/>
                                </Grid>
                                {
                                    eyes.map(e => (
                                        <Grid key={e} item xs={12}>
                                            <Grid container spacing={2}>
                                                <Grid item xs={false} lg={1}>
                                                    {/*// @ts-ignore*/}
                                                    <Box display={"flex"} alignItems={"center"} height={"100%"}>
                                                        <Typography variant={"subtitle1"}>
                                                            {e === "rt" ? t`Right` : t`Left`}
                                                        </Typography>
                                                    </Box>
                                                </Grid>
                                                <Grid item lg={11}>
                                                    <Grid container spacing={3}>
                                                        {
                                                            arr.map(f => {
                                                                const name = `raw_data.${e}${f.name}`;
                                                                return (
                                                                    <Grid key={name} item xs={12} lg={2}>
                                                                        <GeneratedField
                                                                            name={name}
                                                                            disabled={(e === "rt" && !store.rightEnabled) || (e === "lt" && !store.leftEnabled)}
                                                                            label={f.desc}
                                                                            eye={e}
                                                                            isSelect={!f.increment}
                                                                            options={f.options}
                                                                            field={f}
                                                                        />
                                                                    </Grid>
                                                                )
                                                            })
                                                        }
                                                    </Grid>
                                                </Grid>
                                            </Grid>
                                        </Grid>
                                    ))
                                }
                            </Grid>
                        </Grid>
                    </LevelWrapper>
                ))
            }
        </>
    )
});
