import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ModelInput, useReadonlyContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {RxUniverseStore} from "../../../stores/RxUniverseStore";

export const ReleaseNumberInputField: React.FunctionComponent = observer(() => {
    const isVA = RxUniverseStore.selectedModel.isVA
    const readOnly = useReadonlyContext();
    const required = RxUniverseStore.selectedModel.releaseNumRequired

    const label = isVA ? t`Last 4` : t`Release Number`
    const hint = isVA ? {title: t`Last 4`, text: t`The last 4 digits of the Veteran's Social Security number`}
        : {title: t`Release Number`, text: t`The release number used to track third-party billing or safety contracts`}

    return (
        <ModelInput
            name={"release_number"}
            label={label}
            hint={hint}
            disabled={!required || readOnly}
        />
    )
})