import * as React from 'react';
import {SelectField, useModelContext, useReadonlyContext} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {StyleTypeModel, StyleTypeStore} from "../../../stores/StyleTypeStore";
import {sortedOptions} from "../../../stores/_FieldConstants";
import { t } from '@lingui/macro';

export const StyleTypeSelect = observer(() => {
    const model = useModelContext();
    const readOnly = useReadonlyContext();

    React.useEffect(() => {
        StyleTypeStore.getData();
    }, [])

    const style_types = StyleTypeStore.models as StyleTypeModel[];
    const options = style_types.map(st => {
        return {
            label: st.style_type,
            value: st.getId()
        }
    })

    const handleChange = React.useCallback((name, value) => {
        model.nestedAssignment('style_id', null);
        model.nestedAssignment('style_material_id', null);
        model.handleSelectChange(name, value);
    }, [model])

    const value = model.viewModel.dig("style_type_id");

    return (
        <SelectField
            name={"style_type_id"}
            label={t`Type`}
            disabled={!!model.viewModel.quick_code_id || readOnly}
            options={sortedOptions(options)}
            loading={StyleTypeStore.isLoading}
            error={!!StyleTypeStore.fetchErr || !!model.errors.style_type_id}
            helperText={StyleTypeStore.fetchErr || model.errors.style_type_id}
            onChange={handleChange}
            value={(value || value === 0) ? value : null}
        />
    )
});