import {observer, Observer} from "mobx-react-lite";
import * as React from 'react';
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";
import ReactTable, {Column} from 'react-table';
import {t} from "@lingui/macro";
import {ButtonField} from "@rx-suite/ui";
import {FrameCandidate} from "../../../stores/_FieldConstants";
import {FormHelperText} from "@material-ui/core";

export const FrameFindTable = observer(() => {
    const store = useOrderEntryStore();
    const error = store.fetchingFrameCandidatesError;
    const columns = [
        {
            Header: t`UPC`,
            accessor: 'upc',
        },
        {
            Header: t`Manufacturer UPC`,
            accessor: 'manufacturer_upc',
        },
        {
            Header: t`Name`,
            accessor: 'name',
        },
        {
            Header: t`Collection`,
            accessor: 'collection',
        },
        {
            Header: t`Brand`,
            accessor: 'brand',
        },
        {
            Header: t`Model`,
            accessor: 'frame_model',
        },
        {
            Header: t`Manufacturer`,
            accessor: 'manufacturer',
        },
        {
            Header: t`Material`,
            accessor: 'material',
        },
        {
            Header: t`Gender`,
            accessor: 'gender',
        },
        {
            Header: t`Class`,
            accessor: 'frame_class',
        },
        {
            Header: t`Edge`,
            accessor: 'edge_type_name',
        },
        {
            id: '_select',
            accessor: model => model,
            Cell: (row: { original: FrameCandidate | null | undefined }) => {
                if (!row.original) {
                    return null;
                }
                return (
                    <Observer>
                        {
                            () => {
                                return <ButtonField
                                    text={t`Select`}
                                    onClick={() => {
                                        store.applyFrame(row.original!);
                                    }}
                                />
                            }
                        }
                    </Observer>
                )
            },
        },
    ] as Column[];
    return <>
        {error && <FormHelperText error>{error}</FormHelperText>}
        <ReactTable
            data={store.possibleFrames}
            columns={columns}
            loading={store.fetchingFrameFindOptions}
            sortable={false}
            filterable={false}
        />
    </>
});